KOI8-R

МОСКВА, 9 янв - РИА Новости. Надежды на разрешение в пятницу кризиса с транзитом российского газа в Европу через территорию Украины пока не оправдались. Их появлению способствовала информация о согласии украинской стороны на создание международной мониторинговой экспертной комиссии с участием представителей "Газпрома", однако вечером стало известно, что Киев по-прежнему ставит такой формат механизма контроля за транзитом под сомнение. Россия готова возобновить вынужденно прерванные два дня назад ...